# OK

[![PyPI version](https://img.shields.io/pypi/v/pytest-ok.svg)](https://pypi.org/project/pytest-ok)
[![Python versions](https://img.shields.io/pypi/pyversions/pytest-ok.svg)](https://pypi.org/project/pytest-ok)
[![See Build Status on Travis CI](https://travis-ci.org/ndevenish/pytest-ok.svg?branch=master)](https://travis-ci.org/ndevenish/pytest-ok)
![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)

The ultimate pytest output plugin

## Features

* Prints 'OK' after every test is run


## Installation

You can install "pytest-ok" via `pip`_ from `PyPI`_::

    $ pip install pytest-ok


## License

Distributed under the terms of the `BSD-3` license, "pytest-ok" is free and open source software


## Issues

If you encounter any problems, please file an issue along with a detailed description.
